# -*- coding: UTF-8 -*-
import unittest


class TaskTest(unittest.TestCase):  # 继承unittest.TestCase
    def tearDown(self):
        # 每个测试用例执行之后做操作
        print('22222222-----------over--------------')

    def setUp(self):
        # 每个测试用例执行之前做操作
        print('11111111-----------begin-------------')

    @classmethod
    def tearDownClass(self):
        # 必须使用 @ classmethod装饰器, 所有test运行完后运行一次
        pass

    @classmethod
    def setUpClass(self):
        # 必须使用@classmethod 装饰器,所有test运行前运行一次
        import eval_task

        self.task = eval_task.Task()
        self.configFile_path = "task_config.yaml"

        
    def test_start(self):
        self.task.start(self.configFile_path)

if __name__ == '__main__':
    unittest.main()#运行所有的测试用例

    


# coding=utf-8
from __future__ import print_function

import requests
import os
import time
import json
import sys


from utils import hitc


class Task(object):
    def __init__(self):
        super(Task, self).__init__()

    def start(self, configFile):
        res = self._do_eval(configFile)
        return res

        # task_name: "job_test_2019050702" #required
        # profile_id: "newk8s666"          #required????????????????/
        # param_ids: "D://job_test"        #required
        # images_dataset_id: "resnet-v1"   #required
        # pr_dataset_id: "TEAM-ALGORITHM-PLAT" #required
        # gt_dataset_id: 1                    #required
        # algo_task_type_id: 1                       #required
        # desc: 3  #optional
        # auth_resource_info:
        #   level:
        #   dept_id:

    # 任务执行
    def _do_eval(self, configFile):
        # ./hitc valtask submit -f configFile
        command = ["valtask", "submit", "-f %s"%configFile]  
        return hitc(command)
    

# 发起评测任务
# name: 评测任务名称
# algo_task_type_id: 算法任务类型ID
# profile_id: 评测代码包的ID
# params_ids: 评测参数的ID列表，可以设置多个
# images_dataset_id: Dataspace中dataset的ID
# gt_dataset_id: Dataspace中gt的ID
# pr_dataset_id: Dataspace中pr的ID
# dept: 模型所属的部门名称 支持 auto aiot platform
# level: 模型资源的权限级别，支持 private public
# 返回空表明创建成功，返回非空表示创建失败，返回的信息为失败原因
def start_eval(name, algo_task_type_id, profile_id, params_ids,
               images_dataset_id, gt_dataset_id, pr_dataset_id, dept, level):
    res = _do_eval(name, algo_task_type_id, profile_id, params_ids,
                   images_dataset_id, gt_dataset_id, pr_dataset_id, dept,
                   level)
    if res.get("code") != 0:
        return res.get("err_user_msg")
    return ""


def _do_eval(name, algo_task_type_id, profile_id, params_ids,
             images_dataset_id, gt_dataset_id, pr_dataset_id, dept, level):
    payload = {
        "name": name,
        "algo_task_type_id": algo_task_type_id,
        "profile_id": profile_id,
        "params_ids": params_ids,
        "images_dataset_id": images_dataset_id,
        "gt_dataset_id": gt_dataset_id,
        "pr_dataset_id": pr_dataset_id,
        "auth_info": {
            "level": level,
            "deptid": dept
        }
    }
    print(payload)
    r = requests.post("http://" + url + "/api/evaluation/v1/val-task",
                      json=payload,
                      headers={"Digest": md5, "uid": uid, "uname": uname})
    print(r)
    print(r.json())
    return r.json()



# coding=utf-8
from __future__ import print_function

import os
import sys
import re

import time
import json
import platform
import requests

from utils import hitc


class Model(object):
    def __init__(self):
        super(Model, self).__init__()

    # 算法模型单条创建
    def save_one(self, name, task_type, json_path, param_path, dept, level):
        command = ["model", "create", "-n", name, "-t", task_type, "-j", json_path, "-p", param_path,"--dept", dept, "--perm", level]  
        return hitc(command)

    # 算法模型单条创建_多版本
    def save_one_append(self, name, task_type, json_path, param_path, dept, level):
        command = ["model", "create", "-n", name, "-t", task_type, "-j", json_path, "-p", param_path,"--dept", dept, "--perm", level]  
        return hitc(command)


    # 算法模型多条创建
    def save(self, name, task_type, json_paths, param_paths, dept, level):
        result = []
        begin = 0

        res = self.save_one(
                    name, task_type, json_paths[0], param_paths[0], dept, level
                )

        if res.startswith("success"):
            begin = 1
            result.append('succeed : {} {} {} {} {} {}'.format(name, task_type, json_paths[0], param_paths[0], dept, level))


        #model create failed, error: GPU model name already exist.
        elif re.search("name already exist", res):
            begin = 0

            ####append 命令追加成功 删除以下两行代码
            result.append('failed : {} '.format(res))
            return result


        for json_path, param_path in zip(json_paths[begin:], param_paths[begin:]):

            res = self.save_one_append(
                    name, task_type, json_path, param_path, dept, level
                )
            
            if not res.startswith("success"):
                result.append('failed : {} {} {} {} {} {}'.format(name, task_type, json_path, param_path, dept, level))

            else:
                result.append('succeed : {} {} {} {} {} {}'.format(name, task_type, json_path, param_path, dept, level))
       
        return result

    # 算法模型下载
    def download(self, idx):
        #model download --id
        command = ["model", "download",  "--id", str(idx)] 
        res = hitc(command)
        if res.startswith("model get failed"):
            return res

        elif res.startswith("panic: interface conversion: interface {} is nil"):
            return res

        else:
            print ("download model id %s "%str(idx))
            return  "success"
    
    # 算法模型单条删除
    def delete(self, idx):
        # Are you sure to delete gpu model dir:  first_modelv1.6
        # y/n?
        # yes
        # success
        if not isinstance(idx ,int):
            print ("id :%s is error"%idx)
            return

        res = hitc(["model", "delete", "--help"])#.stdout.read()
        # res = hitcx(["model", "delete", "-k", str(idx)])#.stdout.read()
        # print (dir(res))
        # print (res.stdout.read())
        # p.stdin.flush()
        print (res)
        # if res.startswith("Are you sure to delete gpu model"):
        #     print ("????????")
        #     # return hitc(["yes"])
        # else:
        return res  



# 保存模型
# name: 模型名称
# task_type: 模型所属的算法任务类型
# json_paths: 需要保存的模型JSON名称列表
# param_paths: 需要保持的模型Params名称列表
# dept: 模型所属的部门名称 支持 auto aiot platform
# level: 模型资源的权限级别，支持 private public
# 返回空表明创建成功，返回非空表示创建失败，返回的信息为失败原因
def save_model(name, task_type, json_paths, param_paths, dept, level):
    for json_path, param_path in zip(json_paths, param_paths):
        res = save_one_model(
            name, task_type, json_path, param_path, dept, level
        )
        if res.get("code") != 0:
            return res.get("err_user_msg")
    return ""


def save_one_model(name, task_type, json_path, param_path, dept, level):
    payload = {}
    payload["container_json_path"] = os.path.join(
        host_path, os.path.relpath(json_path, container_path))
    payload["container_param_path"] = os.path.join(
        host_path, os.path.relpath(param_path, container_path))
    payload["name"] = name
    payload["task_type"] = task_type
    payload["auth_info"] = {
        "level": level,
        "deptid": dept
    }
    if job_id:
        payload["job_id"] = int(job_id)
    if project_id:
        payload["project_id"] = int(project_id)
    print(payload)
    r = requests.post(
        "http://" + url + "/api/model/v1/gpumodel",
        json=payload,
        headers={"Digest": md5, "uid": uid, "uname": uname}
    )
    print(r)
    print(r.json())
    return r.json()



import os
from .utils import hitc

# 从容器环境变量中初始化相关信息
md5 = os.getenv("MD5")
# 当前登录用户的ID
uid = os.getenv("UID")
# 当前登录用户的用户名
uname = os.getenv("UName")
# gateway地址
url = os.getenv("gateway_url")
# 训练Job的ID
job_id = os.getenv("jobId")
# 训练Job所属的ProjectID
project_id = os.getenv("projectId")
# 训练生成的模型文件在GlusterFS上的绝对路径
host_path = os.getenv("py_hostpath")
# 训练生成的模型文件在容器内的相对路径
container_path = os.getenv("py_containerpath")


def check_login():
    command = ["who"]
    print ("ccccccccccccccccccccc")
    res = hitc(command)

    if res.startswith("You are not login"):
        command = ["login"]
        res = hitc(command)
        
check_login()


# coding=utf-8
import os
import sys
import subprocess
import platform

def platform_hitc():
    hitc_path = {
        "Windows":"hitc.exe",
        "Linux":"hitc"
    }.get(platform.system(),"hitc")

    def hitc_subprocess(xargs):
        xargs.insert(0,hitc_path)
        child1 = subprocess.Popen(xargs, stdin=subprocess.PIPE, stdout=subprocess.PIPE, shell=True, universal_newlines = True)

        #非阻塞
        return child1.stdout.read()


    return hitc_subprocess

def platform_hitc_block():
    hitc_path = {
        "Windows":"hitc.exe",
        "Linux":"hitc"
    }.get(platform.system(),"hitc")

    def hitc_subprocess(xargs):
        xargs.insert(0,hitc_path)
        child1 = subprocess.Popen(xargs, stdin=subprocess.PIPE, stdout=subprocess.PIPE, shell=True, universal_newlines = True)

        # # 阻塞
        result = child1.communicate(input=None)
        # (k --> ('model create failed, error: GPU model name already exist.\n', None))
        return result[0]

    return hitc_subprocess

hitc = platform_hitc_block()

hitc_block = platform_hitc_block()



# if __name__ == "__main__":
#     hitc(["-a","-b","-c"])


# -*- coding: UTF-8 -*-
import unittest
from . import eval_report


class ReportTest(unittest.TestCase):  # 继承unittest.TestCase
    def tearDown(self):
        # 每个测试用例执行之后做操作
        print('22222222-----------over--------------')

    def setUp(self):
        # 每个测试用例执行之前做操作
        print('11111111-----------begin-------------')

    @classmethod
    def tearDownClass(self):
        # 必须使用 @ classmethod装饰器, 所有test运行完后运行一次
        pass

    @classmethod
    def setUpClass(self):
        # 必须使用@classmethod 装饰器,所有test运行前运行一次
        self.report = eval_report.Report()
        self.configFile_path = "eval_report.json"

        
    def test_create(self):
        self.report.create(self.configFile_path)
   

if __name__ == '__main__':
    unittest.main()#运行所有的测试用例
    


#!/usr/bin/env python
#-*- coding:utf-8 -*-

#############################################
# File Name: setup.py
# Author: gaoyu
# Mail: xiangqukk@163.com
# Created Time:  2019-8-26
#############################################

from setuptools import setup, find_packages            #这个包没有的可以pip一下

setup(
    name = "olympusx",      #这里是pip项目发布的名称
    version = "1.0.2",  #版本号，数值大的会优先被pip
    keywords = ("pip", "olympus","ffffff"),
    description = "an api of project olympus",
    long_description = "An api for olympus cmd ,that is a service for Programmer",
    license = "SMO Licence",

    url = "https://github.com/gggggaoyu/olympus",     #项目相关文件地址，一般是github
    author = "gaoyu",
    author_email = "xiangqukk@163.com",

    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires = ["requests"]          #这个项目需要的第三方库
)
